@@ -597,9 +597,10 @@ impl VsMgmt for MapxRawVs {
         &self,
         branch_name: BranchName,
         version_name: VersionName,
+        force: bool,
     ) -> Result<()> {
         self.inner
-            .branch_create(branch_name.0, version_name.0)
+            .branch_create(branch_name.0, version_name.0, force)
             .c(d!())
     }
 
@@ -610,6 +611,7 @@ impl VsMgmt for MapxRawVs {
         branch_name: BranchName,
         version_name: VersionName,
         base_branch_name: ParentBranchName,
+        force: bool,
     ) -> Result<()> {
         self.inner
             .branch_get_id_by_name(BranchName(base_branch_name.0))
@@ -620,6 +622,7 @@ impl VsMgmt for MapxRawVs {
                         branch_name.0,
                         version_name.0,
                         base_br_id,
+                        force,
                     )
                     .c(d!())
             })
@@ -633,6 +636,7 @@ impl VsMgmt for MapxRawVs {
         version_name: VersionName,
         base_branch_name: ParentBranchName,
         base_version_name: VersionName,
+        force: bool,
     ) -> Result<()> {
         let base_br_id = self
             .inner
@@ -648,6 +652,7 @@ impl VsMgmt for MapxRawVs {
                 version_name.0,
                 base_br_id,
                 base_ver_id,
+                force,
             )
             .c(d!())
     }
@@ -660,9 +665,10 @@ impl VsMgmt for MapxRawVs {
     unsafe fn branch_create_without_new_version(
         &self,
         branch_name: BranchName,
+        force: bool,
     ) -> Result<()> {
         self.inner
-            .branch_create_without_new_version(branch_name.0)
+            .branch_create_without_new_version(branch_name.0, force)
             .c(d!())
     }
 
@@ -675,6 +681,7 @@ impl VsMgmt for MapxRawVs {
         &self,
         branch_name: BranchName,
         base_branch_name: ParentBranchName,
+        force: bool,
     ) -> Result<()> {
         self.inner
             .branch_get_id_by_name(BranchName(base_branch_name.0))
@@ -684,6 +691,7 @@ impl VsMgmt for MapxRawVs {
                     .branch_create_by_base_branch_without_new_version(
                         branch_name.0,
                         base_br_id,
+                        force,
                     )
                     .c(d!())
             })
@@ -699,6 +707,7 @@ impl VsMgmt for MapxRawVs {
         branch_name: BranchName,
         base_branch_name: ParentBranchName,
         base_version_name: VersionName,
+        force: bool,
     ) -> Result<()> {
         let base_br_id = self
             .inner
@@ -713,6 +722,7 @@ impl VsMgmt for MapxRawVs {
                 branch_name.0,
                 base_br_id,
                 base_ver_id,
+                force,
             )
             .c(d!())
     }
