@@ -704,7 +704,12 @@ impl MapxRawMkVs {
 
     #[inline(always)]
     pub(super) fn branch_has_versions(&self, branch_id: BranchID) -> bool {
-        self.branch_exists(branch_id) && !self.branch_to_its_versions.is_empty()
+        self.branch_exists(branch_id)
+            && self
+                .branch_to_its_versions
+                .get(&branch_id)
+                .map(|vers| !vers.is_empty())
+                .unwrap_or(false)
     }
 
     #[inline(always)]
@@ -925,10 +930,10 @@ impl MapxRawMkVs {
         let mut br_vers = self
             .branch_to_its_versions
             .iter()
+            .filter(|(_, vers)| !vers.is_empty())
             .map(|(_, vers)| vers.iter())
             .collect::<Vec<_>>();
-
-        let last_idx = br_vers.len().saturating_sub(1);
+        alt!(br_vers.is_empty(), return Ok(()));
 
         let mut guard = 0;
         let mut vers_to_be_merged = vec![];
@@ -937,11 +942,11 @@ impl MapxRawMkVs {
                 if let Some((ver, _)) = vers.next() {
                     alt!(0 == idx, guard = ver);
                     alt!(guard != ver, break 'x);
-                    alt!(last_idx == idx, vers_to_be_merged.push(guard));
                 } else {
                     break 'x;
                 }
             }
+            vers_to_be_merged.push(guard);
         }
 
         let (vers_to_be_merged, rewrite_ver) = {
@@ -959,7 +964,11 @@ impl MapxRawMkVs {
 
         let rewrite_ver_chgset = self.version_to_change_set.get(rewrite_ver).c(d!())?;
 
-        for (_, vers) in self.branch_to_its_versions.iter() {
+        for (_, vers) in self
+            .branch_to_its_versions
+            .iter()
+            .filter(|(_, vers)| !vers.is_empty())
+        {
             for ver in vers_to_be_merged.iter() {
                 vers.remove(ver).c(d!())?;
             }
